/*
*   Data sent from CasparCG Client as templateData
*   is pushed into corresponding HTML id element
*
*   Usage:
*   insert a script reference in the HTML template header.
*   ex: <script type="text/javascript" src="CasparCG.js"></script>
*   Make sure that the id that you refer to is the innermost tag.
*   Everything within that tag id will be replaced by the value sent from CasparCG
*
*   put together by Tomas Linden
*   modified by Øjvind Søgaard Andersen
*
   Structure of data sent from CasparCG:
   <templateData>
      <componentData id="#idCaspar#">
         <data id="text" value="#valCaspar#" />
      </componentData>
      :
      :
      <componentData id="#idCaspar#">
         <data id="text" value="#valCaspar#" />
      </componentData>
   </templateData>
*/
// Global variable for data from CasparCG
var dataCaspar = {};

// Replace characters that could become a problem if left as is
function escapeHtml(unsafe) {
  return unsafe.replace(/&/g, "&amp;").replace(/</g, "&lt;").replace(/>/g, "&gt;").replace(/"/g, "&quot;").replace(/'/g, "&#039;");
}

// Parse templateData into an XML object
function parseCaspar(str) {
  var xmlDoc;
  if (window.DOMParser) {
    parser = new DOMParser();
    xmlDoc = parser.parseFromString(str, "text/xml");
  }
  dataCaspar = XML2JSON(xmlDoc.documentElement.childNodes);
	
}


// Make the XML templateData message into a more simple key:value object
function XML2JSON(node) {
  var data = {}; // resulting object
  for (k = 0; k < node.length; k++) {
    var idCaspar = node[k].getAttribute("id");
    var valCaspar = node[k].childNodes[0].getAttribute("value");
    if (idCaspar != undefined && valCaspar != undefined) {
      data[idCaspar] = valCaspar;
    };
  }
  return data;
	
}

// Main function to insert data
function dataInsert(dataCaspar) {
  for (var idCaspar in dataCaspar) {
    var idTemplate = document.getElementById(idCaspar);
    if (idTemplate != undefined) {
      idTemplate.innerHTML = escapeHtml(dataCaspar[idCaspar]);
    }
  }
	
}

// Call for a update of data from CasparCG client
function update(str) {
  parseCaspar(str); // Parse templateData into an XML object
  dataInsert(dataCaspar); // Insert data
  logos(dataCaspar); // Insert logos
  colors(dataCaspar);  // Insert colors
  }

// insert data from CasparCg client when activated
function play(str) {
	
  parseCaspar(str); // Parse templateData into an XML object
  dataInsert(dataCaspar); // Insert data
	
}

// Call for a next from CasparCG client
function next() {
  //gwd.actions.timeline.play('document.body');
}

// Call for a stop from CasparCG client
function stopTemplate () {
	
	
}
function stop() {
	document.getElementById("bugwrapper").className = "bug-off";
	
	var summaryCheck = document.getElementById("summary")
	if (summaryCheck.classList.contains('summary-on')){
	document.getElementById("bugwrapper").style.opacity = "0";
	document.getElementById("summary").className = "summary-off";
}
	
	var l3rdCheck = document.getElementById("l3rd")
	if (l3rdCheck.classList.contains('l3rd-on')){
	document.getElementById("l3rd").className = "l3rd-off";
}
	setTimeout(window.remove, 1000);
}

function invoke(str) {
	parseCaspar(str); // Parse templateData into an XML object
  	dataInsert(dataCaspar); // Insert data
	if (str = "t1scorecelebration") {
		t1scorecelebration(dataCaspar); // update score
		
	}
	if (str = "t2scorecelebration") {
		t2scorecelebration(dataCaspar); // update score
		
	}
	
	if (str = "addSummary") {
		addSummary(dataCaspar); // add summary
		
	}
	
	if (str = "removeSummary") {
		removeSummary(dataCaspar); // remove summary
		
	}
	
	if (str = "addPopup") {
		addPopup(dataCaspar); // add popup
		
	}
	
	if (str = "removePopup") {
		removePopup(dataCaspar); // remove popup
		
	}
	
	if (str = "addL3rd") {
		addL3rd(dataCaspar); // add l3rd
		
	}
	
	if (str = "removeL3rd") {
		removeL3rd(dataCaspar); // remove l3rd
		
	}
	
	if (str = "addBug") {
		addBug(dataCaspar); // add scorebug
		
	}
	
	if (str = "removeBug") {
		removeBug(dataCaspar); // remove scorebug
		
	}
	
	if (str = "addMatchup") {
		addMatchup(dataCaspar); // add matchup
		
	}
	
	if (str = "removeMatchup") {
		removeMatchup(dataCaspar); // remove matchup
		
	}
	
	if (str = "addLineup") {
		addLineup(dataCaspar); // add lineup
		
	}
	if (str = "removeLineup") {
		removeLineup(dataCaspar); // remove lineup
		
	}
	
	if (str = "changeLogo") {
		changeLogo(dataCaspar); // change logo
		
	}
	
	if (str = "changeColor") {
		changeColor(dataCaspar); // change color
		
	}
	
	if (str = "t1set0won") {
		t1set0won(dataCaspar); // change set to win
		
	}
	
		if (str = "t2set0won") {
		t2set0won(dataCaspar); // change set to win
		
	}
	
		if (str = "t1set1won") {
		t1set1won(dataCaspar); // change set to win
		
	}
			if (str = "t1set2won") {
		t1set2won(dataCaspar); // change set to win
		
	}
	
			if (str = "t1set3won") {
		t1set3won(dataCaspar); // change set to win
		
	}
			if (str = "t2set3won") {
		t2set3won(dataCaspar); // change set to win
		
	}
			if (str = "t2set1won") {
		t2set1won(dataCaspar); // change set to win
		
	}
			if (str = "t2set2won") {
		t2set2won(dataCaspar); // change set to win
		
	}
	
			if (str = "setclear") {
		setclear(dataCaspar); // change set to win
		
	}
}

// Add team logos 
        function logos(dataCaspar) {
		
			if (dataCaspar.hasOwnProperty("t1logo"))
				{
					
					document.getElementById("t1summarylogo").src = escapeHtml(dataCaspar["t1logo"]);
					document.getElementById("t1matchuplogo").src = escapeHtml(dataCaspar["t1logo"]);
				}
			
			if (dataCaspar.hasOwnProperty("t2logo"))
				{		
					
					document.getElementById("t2summarylogo").src = escapeHtml(dataCaspar["t2logo"]) ;
					document.getElementById("t2matchuplogo").src = escapeHtml(dataCaspar["t2logo"]) ;
				}
			
			if (dataCaspar.hasOwnProperty("lineuplogo")){
				
				document.getElementById("lineuplogo").src = escapeHtml(dataCaspar["lineuplogo"]) ;
			}
			
			if (dataCaspar.hasOwnProperty("broadcastlogo"))
			{
				document.getElementById("broadcastlogo").src = escapeHtml(dataCaspar["broadcastlogo"]) ;
				
			}
	
		}



// add colors
		function colors(dataCaspar) {
			
			
			if (dataCaspar.hasOwnProperty("t1color1"))
				{
					document.getElementById("t1color").style.backgroundColor = escapeHtml(dataCaspar["t1color1"]);
					document.getElementById("t1summarycolor").style.backgroundColor = escapeHtml(dataCaspar["t1color1"]);
					document.getElementById("t1matchupcolor").style.backgroundColor = escapeHtml(dataCaspar["t1color1"]);
					document.getElementById("t1-triangle").style.borderTopColor = escapeHtml(dataCaspar["t1color1"]);
					document.getElementById("t1-box").style.backgroundColor = escapeHtml(dataCaspar["t1color1"]);
				}
			
			if (dataCaspar.hasOwnProperty("t2color1"))
			{
				document.getElementById("t2color").style.backgroundColor = escapeHtml(dataCaspar["t2color1"]);
				document.getElementById("t2summarycolor").style.backgroundColor = escapeHtml(dataCaspar["t2color1"]);
				document.getElementById("t2matchupcolor").style.backgroundColor = escapeHtml(dataCaspar["t2color1"]);
				document.getElementById("t2-triangle").style.borderBottomColor = escapeHtml(dataCaspar["t2color1"]);
				document.getElementById("t2-box").style.backgroundColor = escapeHtml(dataCaspar["t2color1"]);
			}
		
			if (dataCaspar.hasOwnProperty("lineupbottomlinecolor"))
				{
				document.getElementById("lineupbottomline").style.backgroundColor = escapeHtml(dataCaspar["lineupbottomlinecolor"]);
				}
		
		
		}

// fade in set wins
		function t1set0won(dataCaspar) {
			document.getElementById("t1set1").className = "emptyset";
			document.getElementById("t1set2").className = "emptyset";
			document.getElementById("t1set3").className = "emptyset";
		}

		function t1set1won(dataCaspar) {
			document.getElementById("t1set1").className = "fullset";
			document.getElementById("t1set2").className = "emptyset";
			document.getElementById("t1set3").className = "emptyset";
		}

		function t1set2won(dataCaspar) {
			document.getElementById("t1set1").className = "fullset";
			document.getElementById("t1set2").className = "fullset";
			document.getElementById("t1set3").className = "emptyset";
		}
		function t1set3won(dataCaspar) {
			document.getElementById("t1set1").className = "fullset";
			document.getElementById("t1set2").className = "fullset";
			document.getElementById("t1set3").className = "fullset";
		}

		function t2set0won(dataCaspar) {
			document.getElementById("t2set1").className = "emptyset";
			document.getElementById("t2set2").className = "emptyset";
			document.getElementById("t2set3").className = "emptyset";
		}
		function t2set1won(dataCaspar) {
			document.getElementById("t2set1").className = "fullset";
			document.getElementById("t2set2").className = "emptyset";
			document.getElementById("t2set3").className = "emptyset";
		}

		function t2set2won(dataCaspar) {
			document.getElementById("t2set1").className = "fullset";
			document.getElementById("t2set2").className = "fullset";
			document.getElementById("t2set3").className = "emptyset";
		}
		function t2set3won(dataCaspar) {
			document.getElementById("t2set1").className = "fullset";
			document.getElementById("t2set2").className = "fullset";
			document.getElementById("t2set3").className = "fullset";
		}

		function setclear(dataCaspar) {
			document.getElementById("t1set1").className = "emptyset";
			document.getElementById("t1set2").className = "emptyset";
			document.getElementById("t1set3").className = "emptyset";
			document.getElementById("t2set1").className = "emptyset";
			document.getElementById("t2set2").className = "emptyset";
			document.getElementById("t2set3").className = "emptyset";
		}

// update Team 1 score
		function t1scorecelebration(dataCaspar) {	
		var fadeIn = document.getElementById('t1scorecelebration');
		fadeIn.classList.toggle('fade');
		
		setTimeout(reset, 2100);
		
		}
// update Team 2 score
		function t2scorecelebration(dataCaspar) {	
		var fadeIn = document.getElementById('t2scorecelebration');
		fadeIn.classList.toggle('fade');
			
		setTimeout(reset2, 2100);
		
		}
// remove class from score celebration
	function reset() {
		
		var fadeIn = document.getElementById('t1scorecelebration');
		fadeIn.classList.toggle('fade');
	}

// remove class from score celebration
	function reset2() {
		var fadeIn = document.getElementById('t2scorecelebration');
		fadeIn.classList.toggle('fade');
		
	}

// add Summary
		function addSummary(dataCaspar) {	
		document.getElementById("summary").className = "summary-on";		
		}

// remove Summary
		function removeSummary(dataCaspar) {	
		document.getElementById("summary").className = "summary-off";		
		}

// add popup
		function addPopup(dataCaspar) {
		document.getElementById("popup").className = "popup-on";
		}

// remove popup
		function removePopup(dataCaspar) {
		document.getElementById("popup").className = "popup-off";
		}

// add l3rd
		function addL3rd(dataCaspar) {
		document.getElementById("l3rd").className = "l3rd-on";
		}

// remove l3rd
		function removeL3rd(dataCaspar) {
		document.getElementById("l3rd").className = "l3rd-off";
		}

// add score bug
		function addBug(dataCaspar) {
		document.getElementById("bugwrapper").className = "bug-on";
		}

// remove score bug
		function removeBug(dataCaspar) {
		document.getElementById("bugwrapper").className = "bug-off";
		}

// add matchup
		function addMatchup(str) {
		parseCaspar(str); // Parse templateData into an XML object
  		dataInsert(dataCaspar); // Insert data
		document.getElementById("matchup").className = "matchup-on";
		}

// remove matchup
		function removeMatchup(dataCaspar) {
		document.getElementById("matchup").className = "matchup-off";
		}

